@@ -4,35 +4,19 @@ package Devel::AssertOS::Unix;
 
 use Devel::CheckOS;
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 # list of OSes lifted from Module::Build 0.2808
 #
-sub os_is {
-    Devel::CheckOS::os_is('AIX') ||
-    Devel::CheckOS::os_is('BSDOS') ||
-    Devel::CheckOS::os_is('DGUX') ||
-    Devel::CheckOS::os_is('DragonflyBSD') ||
-    Devel::CheckOS::os_is('Dynix') ||
-    Devel::CheckOS::os_is('FreeBSD') ||
-    Devel::CheckOS::os_is('HPUX') ||
-    Devel::CheckOS::os_is('Interix') ||
-    Devel::CheckOS::os_is('Irix') ||
-    Devel::CheckOS::os_is('Linux') ||
-    Devel::CheckOS::os_is('MachTen') ||
-    Devel::CheckOS::os_is('MacOSX') ||
-    Devel::CheckOS::os_is('MirOSBSD') ||
-    Devel::CheckOS::os_is('NetBSD') ||
-    Devel::CheckOS::os_is('OpenBSD') ||
-    Devel::CheckOS::os_is('OSF') ||
-    Devel::CheckOS::os_is('QNX') ||
-    Devel::CheckOS::os_is('SCO') ||
-    Devel::CheckOS::os_is('Solaris') ||
-    Devel::CheckOS::os_is('SunOS') ||
-    Devel::CheckOS::os_is('SysVr4') ||
-    Devel::CheckOS::os_is('SysVr5') ||
-    Devel::CheckOS::os_is('Unicos')
+sub matches {
+    return qw(
+        AIX BSDOS DGUX DragonflyBSD Dynix FreeBSD HPUX Interix Irix
+        Linux MachTen MacOSX MirOSBSD NetBSD OpenBSD OSF QNX SCO Solaris
+        SunOS SysVr4 SysVr5 Unicos
+    );
 }
+sub os_is { Devel::CheckOS::os_is(matches()); }
+Devel::CheckOS::die_unsupported() unless(os_is());
 
 sub expn {
 join("\n", 
@@ -44,8 +28,6 @@ join("\n",
 )
 }
 
-Devel::CheckOS::die_unsupported() unless(os_is());
-
 =head1 COPYRIGHT and LICENCE
 
 Copyright 2007 - 2008 David Cantrell
